"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = require("node-fetch");
const cheerio = require("cheerio");
class Blocks {
    async player(username) {
        if (typeof username !== 'string')
            throw new TypeError(`[BlocksMC] expected string on username, got ${typeof username}`);
        return this._getData({ type: 'player', username });
    }
    async top(game) {
        if (typeof game !== 'string')
            throw new TypeError(`[BlocksMC] expected string on username, got ${typeof game}`);
        return this._getData({ type: 'top', game });
    }
    async _getData(options) {
        if (options.type === 'player') {
            const data = { games: [] };
            const res = await node_fetch_1.default(`https://blocksmc.com/player/${options.username}`);
            const rawData = await res.text();
            const $ = cheerio.load(rawData);
            const rank = $('.profile-rank').text().replace('\n', '')
                .trim();
            const timePlayed = $('h1[dir=ltr]').text().replace('\n', '')
                .trim();
            const name = $('.profile-header h1').text();
            if (name)
                Object.assign(data, { name });
            if (rank)
                Object.assign(data, { rank });
            if (timePlayed)
                Object.assign(data, { timePlayed });
            $('div.col-xl-4').each(function () {
                const stats = {};
                $(this).find('li').each(function () {
                    Object.assign(stats, { [$(this).find('div.key').text()]: $(this).find('div.val').text() });
                });
                data.games.push({
                    game: $(this).find('div.title').text()
                        .trim(),
                    stats
                });
            });
            return data;
        }
        if (options.type === 'top') {
            const data = [];
            const res = await node_fetch_1.default(`https://blocksmc.com/${options.game}`);
            const rawData = await res.text();
            const $ = cheerio.load(rawData);
            $('tbody').find('a').each(function () {
                data.push($(this).text());
            });
            return data;
        }
    }
}
exports.default = Blocks;

//# sourceMappingURL=Blocks.js.map
